import 'package:flutter/widgets.dart';

class DoubleTextEditingController extends TextEditingController {
  DoubleTextEditingController({String text}) : super(text: text) {
    addListener(_textEditingListener);
  }

  void _textEditingListener() {
    text = getDoubleString(text);
  }

  String _prevValue = '';

  @override
  set text(String value) {
    if (super.text != value) {
      super.text = getDoubleString(value);
      selection = TextSelection(baseOffset: _prevValue.length, extentOffset: _prevValue.length);
    }
  }

  String getDoubleString(String toDouble) {
    if (toDouble == null || toDouble.isEmpty) {
      return '';
    }
    final String newValue = toDouble.replaceAll(RegExp(r'[^0-9\.,]'), '').replaceAll(RegExp(r'(,+)|(\.{2,})'), '.').replaceAll(RegExp(r'(-)|( )|(^\.)'), '');
    if (RegExp(r'\..*\.').hasMatch(newValue)) {
      return _prevValue;
    }
    if (newValue.isEmpty) {
      return '';
    }
    _prevValue = newValue;
    return newValue;
  }

  @override
  void dispose() {
    removeListener(_textEditingListener);
    super.dispose();
  }
}
